@@ -3,6 +3,7 @@ from __future__ import unicode_literals
 
 import re
 import sys
+import time
 from datetime import datetime
 
 import mock
@@ -21,6 +22,10 @@ from mollie.api.error import (
     UnauthorizedError,
     UnprocessableEntityError,
 )
+from mollie.api.objects.method import Method
+from mollie.api.objects.organization import Organization
+
+from .utils import assert_list_object
 
 
 @pytest.mark.parametrize('params, querystring', [
@@ -46,7 +51,7 @@ def test_client_querystring(client, response):
 
     params = {'amount': {'currency': 'USD', 'value': '100.00'}}
     methods = client.methods.list(**params)
-    assert methods.count == 11
+    assert_list_object(methods, Method)
 
 
 def test_client_api_key():
@@ -92,7 +97,7 @@ def test_client_invalid_api_key():
 
 def test_client_api_key_during_init_deprecated(recwarn):
     """Setting the api key during init should work but raise a warning."""
-    with pytest.warns(PendingDeprecationWarning,
+    with pytest.warns(DeprecationWarning,
                       match='Setting the API key during init will be removed in the future'):
         client = Client(api_key='test_123')
     assert client.api_key == 'test_123'
@@ -319,7 +324,7 @@ def test_client_data_consistency_error(client, response):
 def test_client_default_user_agent(client, response):
     """Default user-agent should contain some known values."""
 
-    regex = re.compile(r'^Mollie/[\d\.]+ Python/[\d\.]+ OpenSSL/\w+')
+    regex = re.compile(r'^Mollie/[\d\.]+ Python/[\w\.\+]+ OpenSSL/[\w\.]+$')
     assert re.match(regex, client.user_agent)
 
     # perform a request and inpect the actual used headers
@@ -329,8 +334,21 @@ def test_client_default_user_agent(client, response):
     assert re.match(regex, request.headers['User-Agent'])
 
 
-def test_client_user_agent_with_oauth():
-    """When authenticating with an access token, the User-Agent should cont an OAuth component."""
+def test_oauth_client_default_user_agent(oauth_client, response):
+    """Default user-agent should contain some known values."""
+
+    regex = re.compile(r'^Mollie/[\d\.]+ Python/[\w\.\+]+ OpenSSL/[\w\.]+ OAuth/2.0$')
+    assert re.match(regex, oauth_client.user_agent)
+
+    # perform a request and inpect the actual used headers
+    response.get('https://api.mollie.com/v2/organizations/me', 'organization_current')
+    oauth_client.organizations.get('me')
+    request = response.calls[0].request
+    assert re.match(regex, request.headers['User-Agent'])
+
+
+def test_client_user_agent_with_access_token():
+    """When authenticating with an access token, the User-Agent should contain an OAuth component."""
     client = Client()
     assert 'OAuth'.lower() not in client.user_agent.lower()
     client.set_access_token('access_123')
@@ -401,3 +419,35 @@ def test_client_update_user_agent_component():
     assert 'Test/3.0.0' in client.user_agent
     assert 'Test/2.0.0' not in client.user_agent
     assert 'Test/1.0.0' not in client.user_agent
+
+
+def test_oauth_client_will_refresh_token_automatically(oauth_token, response):
+    """Initializing the client with an expired token will trigger a token refresh automatically."""
+
+    # expire the token: set expiration time in the past.
+    oauth_token["expires_at"] = time.time() - 5
+
+    set_token_mock = mock.Mock()
+
+    client = Client()
+    client.setup_oauth(
+        client_id="client_id",
+        client_secret="client_secret",
+        redirect_uri="https://example.com/callback",
+        scope=("organizations.read",),
+        token=oauth_token,
+        set_token=set_token_mock,
+    )
+
+    # setup two request mocks: the token refresh and the actual data request
+    response.post("https://api.mollie.com/oauth2/tokens", "token_single")
+    response.get("https://api.mollie.com/v2/organizations/me", "organization_current")
+
+    organization = client.organizations.get('me')
+    assert isinstance(organization, Organization), "Unexpected result from request."
+    assert response.assert_all_requests_are_fired, "Not all expected requests have been performed."
+
+    # verify handling of the new token
+    set_token_mock.assert_called_once()
+    args, kwargs = set_token_mock.call_args
+    assert isinstance(args[0], dict), "set_token() did not receive a dictionary."
